==> nodewire-0.4.2.tar.gz: nodewire-0.4.2/nodewire/node.py <==
from NodeWire import NodeWire
import time


class Port:
    def __init__(self, name, props='Digital OUT', writing=None, reading=None):
        self.store = 0
        self.name = name
        self.props = props
        self.writing = writing
        self.reading = reading

    def read(self):
        if(self.reading): self.reading()
        return  self.store

    def write(self, val):
        if(self.writing): self.writing(val)
        self.store = val

    def properties(self):
        return self.props

class Node:
    def __init__(self):
        self.nw = NodeWire('MyNode', account='sadiq.a.ahmad@gmail.com', password='secret', process=self.process)
        self.nw.debug = True
        self.ports = []

    def process(self, msg):
        if msg.Command == 'get' or msg.Command == 'getportvalue':
            if msg.Params[0] == 'properties':
                p = filter(lambda pp: pp.name == msg.Params[1], self.ports)
                if len(p) != 0: self.nw.send(msg.Sender,'properties', p[0].name, p[0].properties())
            elif msg.Params[0] == 'ports':
                ps = ''
                for p in self.ports: ps = ps + ' ' + p.name
                self.nw.send(msg.Sender, 'ports', ps)
            else:
                v = self.get(msg.Params[0])
                self.nw.send(msg.Sender, 'portvalue', msg.Params[0], v)
        elif msg.Command == 'set' or msg.Command == 'setportvalue':
            self.set(msg.Params[0], msg.Params[1])
            self.nw.send(msg.Sender, 'portvalue', msg.Params[0], self.get(msg.Params[0]))

    def get(self, port):
        p = filter(lambda pp: pp.name==port, self.ports)
        if len(p) != 0: return p[0].read()
        else: return 'error'

    def set(self, port, val):
        p = filter(lambda pp: pp.name == port, self.ports)
        if len(p) != 0: p[0].write(val)

if __name__ == '__main__':
    node = Node()
    node.ports.append(Port('Power'))
    node.ports.append(Port('LED', 'Digital IN'))
    while True:
        time.sleep(20)

==> nodewire-0.5.1.tar.gz: nodewire-0.5.1/nodewire/node.py <==
from NodeWire import NodeWire
import time


class Port:
    def __init__(self, name, props='Digital OUT', writing=None, reading=None):
        self.store = 0
        self.name = name
        self.props = props
        self.writing = writing
        self.reading = reading

    def read(self):
        if(self.reading): self.reading()
        return  self.store

    def write(self, val):
        if(self.writing): self.writing(val)
        self.store = val

    def properties(self):
        return self.props

class Node:
    def __init__(self, nodename='MyNode', account='sadiq.a.ahmad@gmail.com', password='secret'):
        self.nw = NodeWire(nodename, account, password, process=self.process)
        self.ports = []

    def process(self, msg):
        if msg.Command == 'get' or msg.Command == 'getportvalue':
            if msg.Params[0] == 'properties':
                p = filter(lambda pp: pp.name == msg.Params[1], self.ports)
                if len(p) != 0: self.nw.send(msg.Sender,'properties', p[0].name, p[0].properties())
            elif msg.Params[0] == 'ports':
                ps = ''
                for p in self.ports: ps = ps + ' ' + p.name
                self.nw.send(msg.Sender, 'ports', ps)
            else:
                v = self.get(msg.Params[0])
                self.nw.send(msg.Sender, 'portvalue', msg.Params[0], v)
        elif msg.Command == 'set' or msg.Command == 'setportvalue':
            self.set(msg.Params[0], msg.Params[1])
            self.nw.send(msg.Sender, 'portvalue', msg.Params[0], self.get(msg.Params[0]))

    def get(self, port):
        p = filter(lambda pp: pp.name==port, self.ports)
        if len(p) != 0: return p[0].read()
        else: return 'error'

    def set(self, port, val):
        p = filter(lambda pp: pp.name == port, self.ports)
        if len(p) != 0: p[0].write(val)

if __name__ == '__main__':
    node = Node()
    node.ports.append(Port('Power'))
    node.ports.append(Port('LED', 'Digital IN'))
    while True:
        time.sleep(20)
